summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--lib/ansible/plugins/shell/powershell.py4
1 files changed, 2 insertions, 2 deletions
diff --git a/lib/ansible/plugins/shell/powershell.py b/lib/ansible/plugins/shell/powershell.py
index b883dead22..87f1e2b4ae 100644
--- a/lib/ansible/plugins/shell/powershell.py
+++ b/lib/ansible/plugins/shell/powershell.py
@@ -108,9 +108,9 @@ class ShellModule(object):
else:
return self._encode_script('''Remove-Item "%s" -Force;''' % path)
- def mkdtemp(self, basefile, system=False, mode=None):
+ def mkdtemp(self, basefile, system=False, mode=None, tmpdir=None):
basefile = self._escape(self._unquote(basefile))
# FIXME: Support system temp path!
return self._encode_script('''(New-Item -Type Directory -Path $env:temp -Name "%s").FullName | Write-Host -Separator '';''' % basefile)
def expand_user(self, user_home_path):
@@ -108,9 +108,9 @@ class ShellModule(object):
basefile = self._escape(self._unquote(basefile))
- # FIXME: Support system temp path!
+ # FIXME: Support system temp path and passed in tmpdir!
return self._encode_script('''(New-Item -Type Directory -Path $env:temp -Name "%s").FullName | Write-Host -Separator '';''' % basefile)
def expand_user(self, user_home_path):